pub struct ParseError {
message: String,
labels: Vec<(Span, Cow<'static, str>)>,
notes: Vec<String>,
}Fields
message: Stringlabels: Vec<(Span, Cow<'static, str>)>notes: Vec<String>Implementations
Sourceimpl ParseError
impl ParseError
pub fn labels(&self) -> impl ExactSizeIterator<Item = (Span, &str)> + '_
pub fn message(&self) -> &str
fn diagnostic(&self) -> Diagnostic<()>
Sourcepub fn emit_to_string(&self, source: &str) -> String
pub fn emit_to_string(&self, source: &str) -> String
Emits a summary of the error to a string.
Sourcepub fn emit_to_string_with_path<P>(&self, source: &str, path: P) -> String
pub fn emit_to_string_with_path<P>(&self, source: &str, path: P) -> String
Emits a summary of the error to a string.
Sourcepub fn location(&self, source: &str) -> Option<SourceLocation>
pub fn location(&self, source: &str) -> Option<SourceLocation>
Returns a SourceLocation for the first label in the error message.